env

package
v0.3.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 26, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	Production  = envar.Production
	Demo        = envar.Demo
	Staging     = envar.Staging
	QA          = envar.QA
	Development = envar.Development
	Local       = envar.Local
)

Variables

This section is empty.

Functions

func GetDeployEnv

func GetDeployEnv() envar.DeployEnv

GetDeployEnv returns the current deployment environment. Deprecated

func Is

func Is(deployEnv envar.DeployEnv) bool

Is returns true if the current deployment environment is greater than or equal to the specified deployment environment. Deprecated

func NewDeployEnv

func NewDeployEnv(name string, value int) envar.DeployEnv

NewDeployEnv DeployEnv represents the deployment environment. Deprecated

Types

This section is empty.

Jump to